@@ -7,6 +7,12 @@ if(package_version(packageDescription("robustbase")$Version) < "0.9.8"
    || !any("raw.only" == names(formals(covMcd))))
     stop("Need a version of 'robustbase' where covMcd(*,raw.only=TRUE) works")
 
+sessionInfo()# see it interactively
+if(!exists("doExtras")) # <-- so you can set it *before*  demo(robcovMCD)
+    doExtras <- simsalapar:::doExtras()
+doExtras
+
+
 ## Here, we will redo part of the simulations done (and reported on) in
 ##
 ## Pison, G., Van Aelst, S., and Willems, G. (2002),
@@ -16,7 +22,9 @@ if(package_version(packageDescription("robustbase")$Version) < "0.9.8"
 ## ~/save/papers/robust-diverse/Pison_VanAelst_Willems.pdf
 
 ## build grid (for the *real* simulation
-varList <- varlist(n.sim = list(type="N", expr = quote(N[sim]), value = 1000),
+varList <- varlist(n.sim = list(type="N", expr = quote(N[sim]),
+			       value = 1024),
+		   ##		       ---- a multiple of block.size = 64 (below)
 		   n     = list(type="grid", expr = quote(n),
 				value = c(10, 15, 20, 30, 35, 40, 60, 100, 200)),
 		   ## Note:  p < n is really "practically" required ...
@@ -26,16 +34,21 @@ varList <- varlist(n.sim = list(type="N", expr = quote(N[sim]), value = 1000),
 				value = 1/2 + (0:8)/16)
 		   )
 
-if(interactive() || exists(".checking")) { ## i.e., when run as a demo, need much smaller sizes
+dim(pGrid <- mkGrid(varList))
+head(pGrid)
+tail(pGrid)
+
+.checking <- exists(".checking") && .checking
+if(interactive() || .checking) { ## i.e., when run as a demo, need much smaller sizes
     message("Redimensioning the variable list in order to finish  ``in time'' ..")
     varList.full <- varList
     varList <- set.n.sim(varList, 512)
     varList$ n    $value <- local({n <- varList$n$value; n[n <= 60]})
     varList$ p    $value <- c(1:4, 7)
     varList$ alpha$value <- c(0.5, 0.75)
+    print(pGrid <- mkGrid(varList))
 }
 
-(pGrid <- mkGrid(varList))
 ng <- get.nonGrids(varList)
 
 ## do1mcd() : to be applied to one line of the grid
@@ -43,7 +56,7 @@ do1mcd <- function(n, p, alpha)
 {
     stopifnot(length(alpha) == 1, 0.5 <= alpha, alpha <= 1,
 	      length(n) == 1, n == round(n), n > 0,
-	      length(p) == 1, p == round(p), n > 0)
+	      length(p) == 1, p == round(p), p > 0)
     X <- matrix(rnorm(n*p), n,p)
     ## Compute  Det(\hat\Sigma) ^ {1/p} :
     mcd <- covMcd(X, alpha=alpha, use.correction=FALSE, raw.only=TRUE)
@@ -65,11 +78,12 @@ vl.sm0 <- varlist(n.sim = list(expr = quote(N[sim]), value = 8),
 		  )
 mkGrid(vl.sm0)# (as basic check) -> 24 rows
 
-options(error = recover)
+if(interactive())
+    options(error = recover)
 system.time(
 r.sm0 <- doLapply(vl.sm0, seed = "seq", subjob.=subjob,
 		  doOne=do1mcd, timer=mkTimer(gcFirst=FALSE))
-)#
+)# 2.2 (lynne 2013)
 ## currently *with* errors :
 str(e <- getArray(r.sm0,"error"))
 print.table(e2 <- apply(e, 1:2, sum), zero=".")# error exactly  iff  p >= n
@@ -78,52 +92,113 @@ stopifnot(identical(which(e2 > 0), c(7L, 10:11)))
 ## a too small list; for testing (type = "N" is automatic for 'n.sim'):
 vl.sml <- varlist(n.sim = list(expr = quote(N[sim]), value = 64),
 		  n     = list(type="grid", expr = quote(n),
-		  value = c(10, 15, 20:24, 30)),
+                               value = c(10, 15, 20:24, 30)),
 		  p     = list(type="grid", expr = quote(p), value = c(1:3, 5)),
 		  alpha = list(type="grid", expr = quote(alpha),
-			       value = 1/2 + (0:2)/4)
+                               value = 1/2 + (0:2)/4)
 		  )
 
-system.time(
-r.sml <- doLapply(vl.sml, seed = "seq",
-	       subjob. = subjob, doOne=do1mcd, timer=mkTimer(gcFirst=FALSE))
-)# ~ 23 sec (MH: 68s :-( )
-
-save(r.sml, vl.sml, file = "robcovMCD-sml-sim.rda")
+smlFile <- "robcovMCD-sml-sim.rda"
+## If the smlFile does not exist _or_ is older than 12 hours, (re)create it :
+if(!file.exists(smlFile) ||
+   Sys.time() - file.info(smlFile)[["ctime"]] > as.difftime(12, units="hours"))
+{
+    cat("recomputing ", smlFile, ": ") ; flush.console()
+    stime.sml <- system.time(
+        r.sml <- doLapply(vl.sml, seed = "seq",
+                          subjob. = subjob, doOne=do1mcd, timer=mkTimer(gcFirst=FALSE)))
+    print(stime.sml)# ~ 23 sec (lynne 2014;  MH: 68s; ada-13: 45.5 sec; nb-mm3: 35.5 sec)
+    save(stime.sml, r.sml, vl.sml, file = smlFile)
+} else {
+    cat("using", smlFile, "from" , format(file.info(smlFile)[["ctime"]]),":\n")
+    load(smlFile)
+}
 
 (v.sml <- getArray(r.sml))
+## Bug: these two plots are already contradicting; first plot is wrong: (p = 2: medians ~ 1.2)
 mayplot(v.sml, vl.sml, row.vars = NULL, col.vars = "alpha", xvar = "n")
-mayplot(v.sml, vl.sml, row.vars = "p", col.vars = "alpha", xvar = "n")
+mayplot(v.sml, vl.sml, row.vars = "p",  col.vars = "alpha", xvar = "n", cex = .5)
 
 
-## now the "big" simulation:
-system.time({
-res <- doForeach(varList, block.size = 64,
+if(! .checking) { ## now the "big" simulation:
+    ##
+print(system.time({
+### res <- doForeach(varList, block.size = 64, <<< 2014-12-04: takes 193 seconds on nb-mm3  ???
+    res <- doClusterApply(varList, block.size = 64,  ## only 23 seonds
                  seed = "seq", #-> no 'seed' needed
+                 extraPkgs = "robustbase", # <--!!{otherwise do1mcd() needs require(.): inefficient}
                  subjob. = subjob, doOne=do1mcd, timer=mkTimer(FALSE))
-})
+}))
+} else {
+    cat("Using  **smaller**  example in the following:\n")
+    res <- r.sml; varList <- vl.sml
+}
+## MH:
+## Warning message:
+## In mkAL(x, vList, repFirst = repFirst, check = check) :
+##   All "value"s are of length zero. The first error message is
+##  "unused argument (`NA` = NULL)"
 
 ## now save "all", including some platform info:
-sess.I <- sessionInfo()
+(sess.I <- sessionInfo())  # see it interactively
 node <- Sys.info()[c("nodename","release")]
 node.I <- c(node, cores = parallel::detectCores())
-save(r.sml, vl.sml, res, varList, do1mcd, sess.I, node.I,
+save(r.sml, vl.sml,
+     res, varList,
+     do1mcd, sess.I, node.I,
      file = sprintf("robcovMCD-sim_%s_%s.rda",
      node[1], format(Sys.Date())))
 
+## For interactive experiments
+if(FALSE)
+    load("robcovMCD-sim_ada-13_2014-11-27.rda")## takes ~ 2 sec !
+if(FALSE)
+    load("~/R/Pkgs/simsalapar.Rcheck-64b/tests/robcovMCD-sim_nb-mm3_2014-12-05.rda")
+
 ## convert array of nice simulated values
 str(val <- getArray(res))
 apply(val, 1:2, mean)## -- see boxplots below
 apply(val, 1:2,   sd)## comparable
 
+tools::assertError(## now gives an *intelligible* error message:
 mayplot(val, varList, pcol="tomato",
-	row.vars = NULL, col.vars = "meth", xvar = "n")
+	row.vars = "meth", col.vars = "p", xvar = "n")
+)
+
+valm <- apply(val, 1:3, median)
+valm[,,"0.75"] - valm[,,"0.50"] # alpha = 0.75 is consistently larger (medians!)
+if(FALSE)## bug in mayplot() -- this gives an error {wrong switch() decision?}
+mayplot(valm, varList, row.vars = NULL, col.vars = "p", xvar = "n", method="lines")
+
+## BUG in  mayplot():
+mayplot(val, varList, row.vars = NULL, col.vars = "p", xvar = "n")
+## looks "fine", but plotting wrong numbers: alpha = 0.75  medians > 1 is not ok !!!
+round(valm[,, "0.75"], 2) ## where all are montonely *increasing* in 'n'
+## which *is* clearly visible here [using new 'cex']:
+mayplot(val, varList, pcol="tomato",
+	row.vars = "alpha", col.vars = "p", xvar = "n", cex = .1, lwd=2)
+
+### Using the dataframe and lattice:
+dval <- array2df(val)
+dvalm <- array2df(valm)
+
+require(lattice)
+## The medians only
+xyplot(value ~ n | p + alpha, data=dvalm, type = c("p","smooth"))
+
+## The full boxplots
+bwplot(value ~ n | p + alpha, data=dval)
+
+bwplot(value ~ n | p + alpha, data=dval, cex=0.75,
+       xlab = "n", ylab = expression(Det(.) ^{1/p}),
+       panel = function(...) { panel.grid(v = -1, h = -1); panel.bwplot(...) },
+       par.settings = list(plot.symbol = list(cex = 0.25))) # smaller outlier symbols
 
 str(times <- getArray(res, "time"))
-table(round(times)) # most are '0'; rest very platform dependent..
+table(round(times)) # of course quite platform dependent..
 
 ## check
-stopifnot(val["100", "robust", 1:3] == res["100", "robust", 1:3]$value)
+stopifnot(val["20", "3", , 1:3] == res["20", "3", , 1:3]$value)
 
 ## Errors (trivial here, due to getArray()'s default FUN for comp="error"):
 errs <- getArray(res, "error")
